import { getAllRoleList } from '@/api/system/role/role';
import { BasicColumn, FormSchema } from '@/components/Table';
import { h } from 'vue';
import { Tag, Switch } from 'ant-design-vue';
import { useMessage } from '@/hooks/web/useMessage';
import { changeFlagApi } from '@/api/system/user/user';
import { DescItem } from '@/components/Description';
import { c } from 'node_modules/vite/dist/node/types.d-aGj9QkWt';
import { t } from '@/hooks/web/useI18n';
// 引入开关组件
type CheckedType = boolean | string | number;

export const ManagePropertySchema: DescItem[] = [
  {
    field: 'resourceCataloging',
    label: '资源编目',
  },
  {
    field: 'ownerInstitution',
    label: '权属机构',
  },
  {
    field: 'label',
    label: 'Label',
  },
];

export const permissionsInfo: DescItem[] = [
  {
    field: 'permissions',
    label: '开放权限',
  },
];
export const BasicInfoSchema: DescItem[] = [
  {
    field: 'creator',
    label: '创建者',
  },
  {
    field: 'createDate',
    label: '创建时间',
  },
  {
    field: 'updateFrequency',
    label: '更新频率',
  },
  {
    field: 'securityClassification',
    label: '安全分级',
  },
  {
    field: 'sourceDataTable',
    label: '源数据表',
  },
  {
    field: 'sourceTableSize',
    label: '源表大小',
  },
  {
    field: 'releaseStatus',
    label: '发布状态',
  },
  {
    field: 'releaser',
    label: '发布者',
  },
  {
    field: 'releaseDate',
    label: '发布时间',
  },
  {
    field: 'describe',
    label: '描述',
  },
];
export const columns: BasicColumn[] = [
  {
    title: '轮播图名称',
    dataIndex: 'name',
    width: 150,
  },
  {
    title: '轮播图文件名',
    dataIndex: 'project',
    width: 150,
  },
  {
    title: '图片',
    dataIndex: 'imgSrc',
    width: 150,
  },
  {
    title: '轮播图描述',
    dataIndex: 'describe',
    width: 150,
  },
  {
    title: '创建者',
    dataIndex: 'creator',
    width: 150,
  },
  {
    title: '创建时间',
    dataIndex: 'createDate',
    width: 150,
  },
  {
    title: '发布状态',
    dataIndex: 'releaseStatus',
    width: 150,
  },
];
export const searchFormSchema: FormSchema[] = [
  {
    field: 'name',
    label: ' ',
    component: 'Input',
    componentProps: {
      placeholder: '搜索轮播图名称',
    },
    colProps: { span: 4 },
  },
  // {
  //   field: 'project',
  //   label: ' ',
  //   component: 'Input',
  //   componentProps: {
  //     placeholder: '搜索轮播图文件名',
  //   },
  //   colProps: { span: 4 },
  // },
  // {
  //   field: 'describe',
  //   label: ' ',
  //   component: 'Input',
  //   componentProps: {
  //     placeholder: '搜索轮播图描述',
  //   },
  //   colProps: { span: 4 },
  // },
  // {
  //   field: 'releaseStatus',
  //   label: ' ',
  //   component: 'Select',
  //   componentProps: {
  //     placeholder: '发布状态',
  //     options: [
  //       { label: '已发布', value: '已发布' },
  //       { label: '发布审批中', value: '发布审批中' },
  //       { label: '未发布', value: '未发布' },
  //     ],
  //   },
  //   colProps: { span: 4 },
  // },
];
export const accountFormSchema: any[] = [
  {
    field: 'name',
    label: '名称',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
    rules: [
      {
        required: true,
        message: '请输入名称',
      },
    ],
  },
  {
    field: 'project',
    label: '轮播图文件名',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
    rules: [
      {
        required: true,
        message: '请输入文件名',
      },
    ],
  },
  {
    field: 'describe',
    label: '轮播图描述',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
    rules: [
      {
        required: true,
        message: '请输入描述',
      },
    ],
  },
  {
    field: 'import',
    label: '上传轮播图',
    slot: 'import',
  },
];
export const EditFormSchema: any[] = [
  {
    field: 'name',
    label: '资源编目',
    component: 'TreeSelect',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      treeData: [
        {
          label: '资源编目管理',
          value: 'server',
          children: [
            {
              label: '一级编目',
              value: 'vm',
            },
            {
              label: '公共安全',
              value: 'physical',
            },
            {
              label: '卫生健康',
              value: 'health',
            },
            {
              label: '文化休闲',
              value: 'leisure',
            },
            {
              label: '经济建设',
              value: 'economic',
            },
            {
              label: '科技教育',
              value: 'technology',
            },
          ],
        },
      ],
    },
    rules: [
      {
        message: '请选择资源编目',
      },
    ],
  },
  {
    field: 'label',
    label: 'Label',
    component: 'Select',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      options: [
        { label: 'Server', value: 'server' },
        { label: 'Network Device', value: 'network_device' },
        { label: 'Storage Device', value: 'storage_device' },
        { label: 'Firewall', value: 'firewall' },
      ],
    },
    rules: [
      {
        message: '请输入Label',
      },
    ],
  },
  {
    field: 'visibleRange',
    label: '权属机构',
    component: 'Select',
    componentProps: {
      options: [
        { label: '机构甲', value: '机构甲' },
        { label: '机构乙', value: '机构乙' },
        { label: '机构丙', value: '机构丙' },
      ],
    },
    colProps: { lg: 24, md: 24 },
    rules: [
      {
        message: '请输入登录名',
      },
    ],
  },
  {
    field: 'resourceNum',
    label: '可见范围',
    component: 'Select',
    componentProps: {
      options: [
        { label: '所有人', value: '所有人' },
        { label: '用户1', value: '用户1' },
        { label: '用户2', value: '用户2' },
      ],
    },
    colProps: { lg: 24, md: 24 },
    rules: [
      {
        message: '请输入',
      },
    ],
  },
];
/**移动*/
export const MoveFormSchema: any[] = [
  {
    field: 'institutionId',
    label: '目标编目',
    component: 'TreeSelect',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      fieldNames: {
        label: 'institutionName',
        value: 'businessId',
      },
      getPopupContainer: () => document.body,
    },
    required: true,
  },
];

/**新增*/
export const AddTreeSchema: any[] = [
  {
    field: 'institutionName',
    label: '编目名称',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
    rules: [
      {
        required: true,
        message: '请输入编目名称',
      },
    ],
  },
  {
    field: 'institutionId',
    label: '上级编目',
    component: 'TreeSelect',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      fieldNames: {
        label: 'institutionName',
        value: 'businessId',
      },
      getPopupContainer: () => document.body,
    },
    required: true,
  },
  // {
  //   field: 'code',
  //   label: '机构编码',
  //   component: 'Input',
  //   colProps: { lg: 24, md: 24 },
  //   rules: [
  //     {
  //       required: true,
  //       message: '请输入机构编码',
  //     },
  //   ],
  // },
];

export const editFormSchema: any[] = [
  {
    field: 'table1',
    slot: 'table1',
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'dataBase',
    label: '数据源：',
    slot: 'dataBase',
    colProps: { lg: 12, md: 12 },
  },
  {
    field: 'libraryName',
    label: '库名：',
    slot: 'libraryName',
    component: 'Input',
    colProps: { lg: 12, md: 12 },
    required: true,
  },
  {
    field: 'tableName',
    label: '表名：',
    slot: 'tableName',
    component: 'Input',
    colProps: { lg: 12, md: 12 },
    required: true,
  },
  {
    field: 'tableType',
    label: '表类型：',
    slot: 'tableType',
    component: 'Select',
    colProps: { lg: 12, md: 12 },
  },
  {
    field: 'tableExplain',
    label: '表注释：',
    slot: 'tableExplain',
    component: 'Select',
    colProps: { lg: 12, md: 12 },
  },
  {
    field: 'storeType',
    label: '存储类型：',
    slot: 'storeType',
    component: 'Select',
    colProps: { lg: 12, md: 12 },
    required: true,
  },
  {
    field: 'isTransaction',
    label: '是否为事务表：',
    slot: 'isTransaction',
    component: 'Select',
    colProps: { lg: 12, md: 12 },
  },
  {
    field: 'table2',
    slot: 'table2',
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'mainDept',
    label: '主责部门：',
    slot: 'mainDept',
    component: 'Input',
    colProps: { lg: 12, md: 12 },
  },
  {
    field: 'isEncrypt',
    label: '是否为事务表：',
    slot: 'isEncrypt',
    component: 'RadioGroup',
    componentProps: {
      options: [
        { label: '是', value: '是' },
        { label: '否', value: '否' },
      ],
    },
    colProps: { lg: 12, md: 12 },
  },
  {
    field: 'table3',
    slot: 'table3',
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'taskName',
    label: '业务定义：',
    slot: 'taskName',
    component: 'Input',
    colProps: { lg: 12, md: 12 },
  },
  {
    field: 'chineseName',
    label: '表中文名：',
    slot: 'chineseName',
    component: 'Input',
    colProps: { lg: 12, md: 12 },
  },
  {
    field: 'isSensitive',
    label: '是否为敏感信息：',
    slot: 'isSensitive',
    component: 'RadioGroup',
    componentProps: {
      options: [
        { label: '是', value: '是' },
        { label: '否', value: '否' },
      ],
    },
    colProps: { lg: 12, md: 12 },
  },
];
